@@ -1,4 +1,4 @@
-# $Id: Ticket.pm 41 2010-06-16 02:11:14Z bobtfish@bobtfish.net $
+# $Id: Ticket.pm 60 2012-10-27 06:43:24Z pplusdomain@gmail.com $
 #
 # RT::Client::REST::Ticket -- ticket object representation.
 
@@ -56,7 +56,7 @@ RT::Client::REST::Ticket -- this object represents a ticket.
 =head1 DESCRIPTION
 
 B<RT::Client::REST::Ticket> is based on L<RT::Client::REST::Object>.
-The representation allows to retrieve, edit, comment on, and create
+The representation allows one to retrieve, edit, comment on, and create
 tickets in RT.
 
 =cut
@@ -162,36 +162,42 @@ sub _attributes {{
         validation  => {
             type    => SCALAR,
         },
+        is_datetime     => 1,
     },
 
     starts          => {
         validation  => {
             type    => SCALAR|UNDEF,
         },
+        is_datetime     => 1,
     },
 
     started         => {
         validation  => {
             type    => SCALAR|UNDEF,
         },
+        is_datetime     => 1,
     },
 
     due             => {
         validation  => {
             type    => SCALAR|UNDEF,
         },
+        is_datetime     => 1,
     },
 
     resolved        => {
         validation  => {
             type    => SCALAR|UNDEF,
         },
+        is_datetime     => 1,
     },
 
     told            => {
         validation  => {
             type    => SCALAR|UNDEF,
         },
+        is_datetime     => 1,
     },
 
     time_estimated  => {
@@ -220,6 +226,7 @@ sub _attributes {{
             type    => SCALAR,
         },
         rest_name   => 'LastUpdated',
+        is_datetime     => 1,
     },
 }}
 
@@ -313,6 +320,13 @@ and therefore the value cannot be changed..
 
 =back
 
+=head2 Attributes storing a time
+
+The attributes which store a time stamp have an additional accessor with the
+suffix C<_datetime> (eg., C<resolved_datetime>).  This allows you can get and
+set the stored value as a DateTime object.  Internally, it is converted into
+the date-time string which RT uses, which is assumed to be in UTC.
+
 =head1 DB METHODS
 
 For full explanation of these, please see B<"DB METHODS"> in
